#
# spec file for package xfce4-mount-plugin
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.14.0
%define plugin mount
%bcond_with git
Name:           xfce4-%{plugin}-plugin
Version:        1.1.6
Release:        1.6
Summary:        Filesystem Mounting Plugin for the Xfce Panel
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/panel-plugins/xfce4-mount-plugin
Source0:        https://archive.xfce.org/src/panel-plugins/%{name}/1.1/%{name}-%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.50.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4ui-2)
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
Requires:       xfce4-panel >= %{panel_version}
Recommends:     %{name}-lang = %{version}
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo

%description
The Mount plugin allows to mount and unmount filesystems from the panel.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{plugin}-lang < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{plugin}-lang = %{version}-%{release}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
  --enable-maintainer-mode \
  --disable-static
%else
%configure --disable-static
%endif
%make_build

%install
%make_install

rm %{buildroot}%{_libdir}/xfce4/panel/plugins/libmount.la

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name} %{name}.lang %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%doc AUTHORS NEWS README
%license COPYING
%{_libdir}/xfce4/panel/plugins/libmount.so
%{_datadir}/xfce4/panel/plugins/xfce4-mount-plugin.desktop
%{_datadir}/icons/hicolor/*/apps/xfce-mount.*

%files lang -f %{name}.lang

%changelog
* Fri Apr 21 2023 Manfred Hollstein <manfred.h@gmx.net>
- Updated to 1.1.5
  * Remove unused old doc/ folder
  * Improve autotools configuration
  * Update copyright year
  * Remove deprecated project files
  * build: Add GLib requirement
  * build: Fix autotools warnings
  * Use xfce_panel_plugin_popup_menu() when possible
  * Replace deprecated XfcePanelImage with GtkImage
  * Use "logo-icon-name" instead of "logo" in about dialog
  * build: Fix intltool lock file problem during make distcheck
  * Update COPYING
  * autoconf: Remove AC_HEADER_STDC
  * Bump version to 1.1.5 after German translation update and
    compilation on FreeBSD 12.2
  * Partly merge in commit 498e6d23 of skunnyk with autotools
    improvements
  * Removed auto-generatable developer documentation, but keep
    Doxyfile for anyone who wants to create the documentation
  * Removed commented-out AC_CHECK lines in configure.ac.in and
    their comments where reasonable as of now
  * Ran 'make update-po' after fixed typo and line removements in
    C file
  * Comment out step by step old AC_CHECKS, explaining the
    reasoning for future reference and discussion, esp. wrt. *NIX
    compilation problems.
  * Revert "remove checks for unused functions from configure.ac"
  * Updated and revised German translation for next release
  * Translation Updates
- Remove _service file
* Mon Dec 28 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Updated to 1.1.5
  * improved autotools setup
  * translation updates
* Mon Dec 21 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.1.4
  * Remove unused variable exclude_devicenames
  * Remove obsolete panel version 4.9 check
  * Remove checks for unused functions from configure.ac
  * Include stdlib because malloc is used
  * Spellfix. Add missing "e" to siz (size)
  * Update URLs from goodies.x.o to docs.x.o (bxo#16168)
  * Fix build with panel 4.15
  * Make build less verbose
  * Another change to the SVG icon file canvas size
  * Updated svg image to have a larger canvas so that the panel can be
    resized up to 192 pixels size
  * Added title to popup menu; even if it is not empty (bxo#14478)
  * https URL instead of http
  * Renamed improperly named member variable of main mountpoint display
    structure
  * Display percentage on progress bar again (regression from port to
    Gtk3)
  * Reformatted popup information with more columns and nicer alignment.
    (bxo#14670)
  * Fix bxo#13624 by not trying to save when closing the plugin, but
    already and only when closing the settings dialog
  * Translation Updates
* Mon Aug 31 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed spec file
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Tue Jul 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Package renamed to follow upstream name xfce4-foo-plugin
- Use lang subpackage for manual edits instead of %%lang_package macro
- Cleaned up spec file
- Added bcond for git master builds
* Mon Aug  6 2018 seife+obs@b1-systems.com
- update to 1.1.3
  * some pointer checks
  * nicer formatting of Makefile and configure
  * translation updates
* Mon Feb 27 2017 seife+obs@b1-systems.com
- update to 1.1.2
  - port to GTK3
  - allow several spaces in mountpoint names
  - support fuseblk devices by not using fusermount -u for them
    (checks for fuse.* now)
- package: do not package ChangeLog, NEWS is enough
* Sun Dec 25 2016 seife+obs@b1-systems.com
- update to version 0.6.7
  - various bugfixes and feaure enhancements, see ChangeLog
  - translation updates
* Mon May 14 2012 gber@opensuse.org
- update to version 0.6.4
  - trim too long device names
  - cleaned-up and consistent error dialogs
  - updated information in the accompanying README file
* Fri Apr 27 2012 gber@opensuse.org
- update to version 0.6.3
  - fix a  bug introduced in 0.6.0, the 'on-mount' command is now
    run asynchronously to avoid blocking the plugin UI
  - translation updates
* Mon Apr 23 2012 gber@opensuse.org
- update to version 0.6.2
  - remove the sudo(8) option, after all experienced users can
    still prepend sudo using custom mount commands
  - translation updates
* Fri Apr 20 2012 gber@opensuse.org
- added documentation files
* Wed Apr 18 2012 gber@opensuse.org
- update to version 0.6.1
  - fixes an issue with translations
* Tue Apr 17 2012 gber@opensuse.org
- corrected source URL
* Tue Apr 17 2012 gber@opensuse.org
- update to version 0.6.0
  - port to panel 4.8/4.9
  - port to libxfce4ui
  - build the plugin as a module
  - use standard icon names, drop old unused icons
  - add a checkbox option to use sudo
  - rewrite config saving/loading
  - general cleanup
- removed xfce4-panel-plugin-mount-0.5.5-fix-missing-include.patch,
  xfce4-panel-plugin-mount-0.5.5-hide-gvfs-fuse-daemon-mount.patch
  which have been incorporated upstream
* Wed Apr  4 2012 gber@opensuse.org
- specfile cleanup
- correct dependencies
- split off -lang subpackage
* Wed Mar  9 2011 gber@opensuse.org
- new package (split off from xfce4-panel-plugins)
